//--------------------------------------------------------------------
//   HG-B40.c
//   Main Module for Distance Measure
//
//   Module No: HG-B40
//   MCU Type : Atmega8
//   Compiler : WinAVR with AVR Studio 4
//   Copyright (c)Hagisonic. All Rights Reserved.
//--------------------------------------------------------------------

//--------------------------------------------------------------------
//	Transmit Port : PORTB.1
//	Receive Port  : External Interrupt 1
//--------------------------------------------------------------------

#include <stdio.h>

#include <avr/io.h>
#include <avr/interrupt.h>

#include "Define.h"
#include "ExtInt.h"
#include "TimerInt.h"

#define F_CPU				8000000		// CPU Clock : 8MHz
#include <util/delay.h>

#define TRIGGER_DELAY		500		// us
#define LOOP_DELAY			100		// ms

void Port_Init(void)
{
	MCUCR = 0x00;				// External Memory Disable

	DDRB = 0x02;				// Ultrasonic Trigger	// PORTB.1
}

void Initialize()
{
	cli();						// Interrupt Disable

	Port_Init();
	ExtInt1_Init();				// External Interrupt Initialize

	sei();						// Interrupt Enable
}

int main(void)
{
	unsigned int measure_time;

	Initialize();

	while (1) {
		TimerInt1_Start();
		sbi(PORTB, 1);				// Ultrasonic Trigger ON
		_delay_us(TRIGGER_DELAY);	// usec
		cbi(PORTB, 1);				// Ultrasonic Trigger OFF

		measure_time = Get_DistanceTime();

		// Using the variable measure_time.
		// for example : Display the measure_time or calculate the distance
		// Comment :
		// 		The Prescallar Set to CPU_CLOCK/8 = 8MHz/8 = 1MHz = 1000000
		// 		Ultrasonic Speed : (3310.6t)(m)/sec (t=Celsius temperature)
		//						   = 346m/sec (t=25)
		// 		distance for 1 interrupt = 346000 / 1000000 = 0.346mm

		_delay_ms(LOOP_DELAY);		// msec
	}
}
